==> zio-aws-networkmanager_2.13-5.17.112.1-sources.jar: zio/aws/networkmanager/model/GetRouteAnalysisResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetRouteAnalysisResponse(
    routeAnalysis: Option[zio.aws.networkmanager.model.RouteAnalysis] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse = {
    import GetRouteAnalysisResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse
      .builder()
      .optionallyWith(routeAnalysis.map(value => value.buildAwsValue()))(
        _.routeAnalysis
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.GetRouteAnalysisResponse.ReadOnly =
    zio.aws.networkmanager.model.GetRouteAnalysisResponse.wrap(buildAwsValue())
}
object GetRouteAnalysisResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.GetRouteAnalysisResponse =
      zio.aws.networkmanager.model
        .GetRouteAnalysisResponse(routeAnalysis.map(value => value.asEditable))
    def routeAnalysis
        : Option[zio.aws.networkmanager.model.RouteAnalysis.ReadOnly]
    def getRouteAnalysis: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.RouteAnalysis.ReadOnly
    ] = AwsError.unwrapOptionField("routeAnalysis", routeAnalysis)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse
  ) extends zio.aws.networkmanager.model.GetRouteAnalysisResponse.ReadOnly {
    override val routeAnalysis
        : Option[zio.aws.networkmanager.model.RouteAnalysis.ReadOnly] = scala
      .Option(impl.routeAnalysis())
      .map(value => zio.aws.networkmanager.model.RouteAnalysis.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse
  ): zio.aws.networkmanager.model.GetRouteAnalysisResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_2.13-5.17.295.2-sources.jar: zio/aws/networkmanager/model/GetRouteAnalysisResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetRouteAnalysisResponse(
    routeAnalysis: Optional[zio.aws.networkmanager.model.RouteAnalysis] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse = {
    import GetRouteAnalysisResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse
      .builder()
      .optionallyWith(routeAnalysis.map(value => value.buildAwsValue()))(
        _.routeAnalysis
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.GetRouteAnalysisResponse.ReadOnly =
    zio.aws.networkmanager.model.GetRouteAnalysisResponse.wrap(buildAwsValue())
}
object GetRouteAnalysisResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.GetRouteAnalysisResponse =
      zio.aws.networkmanager.model
        .GetRouteAnalysisResponse(routeAnalysis.map(value => value.asEditable))
    def routeAnalysis
        : Optional[zio.aws.networkmanager.model.RouteAnalysis.ReadOnly]
    def getRouteAnalysis: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.RouteAnalysis.ReadOnly
    ] = AwsError.unwrapOptionField("routeAnalysis", routeAnalysis)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse
  ) extends zio.aws.networkmanager.model.GetRouteAnalysisResponse.ReadOnly {
    override val routeAnalysis
        : Optional[zio.aws.networkmanager.model.RouteAnalysis.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.routeAnalysis())
        .map(value => zio.aws.networkmanager.model.RouteAnalysis.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.GetRouteAnalysisResponse
  ): zio.aws.networkmanager.model.GetRouteAnalysisResponse.ReadOnly =
    new Wrapper(impl)
}
